require "date"
require "git/stats/repo"

module Git
  module Stats
    class Statistic
      attr_accessor :folder, :branch, :options

      def initialize(folder, branch, options = {})
        # TODO: Check folder
        @folder = folder
        # TODO: Check branch
        @branch = branch || "develop"
        @options = options
      end

      def statistic
        result = {}

        stats = filter_commits.group_by { |commit| commit.author_email }
        stats.each do |author, commits|
          month_stats = commits.group_by { |c| c.date.strftime("%Y-%m") }
          info = {}
          month_stats.each do |month, value|
            info[month] = {
              commits: value.length,
              files: 0,
              insertions: 0,
              deletions: 0
            }
            value.each do |c|
              info[month][:files] += c.stats[:files]
              info[month][:insertions] += c.stats[:insertions]
              info[month][:deletions] += c.stats[:deletions]
            end
          end
          result[author] = info
        end

        result
      end

      def filter_commits
        repo = Repo.new(@folder, @branch)
        commits = repo.commits

        if options[:start_date]
          commits = commits.select { |commit| commit.date >= options[:start_date] }
        end

        commits
      end

      class << self
        def statistic(folder, branch, options = {})
          new(folder, branch, options).statistic
        end
      end
    end
  end
end